@@ -3,7 +3,7 @@
 /*
     Rubber Band Library
     An audio time-stretching and pitch-shifting library.
-    Copyright 2007-2021 Particular Programs Ltd.
+    Copyright 2007-2022 Particular Programs Ltd.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -24,10 +24,9 @@
 #ifndef RUBBERBAND_COMPOUND_AUDIO_CURVE_H
 #define RUBBERBAND_COMPOUND_AUDIO_CURVE_H
 
-#include "dsp/AudioCurveCalculator.h"
 #include "PercussiveAudioCurve.h"
 #include "HighFrequencyAudioCurve.h"
-#include "dsp/SampleFilter.h"
+#include "../dsp/SampleFilter.h"
 
 namespace RubberBand
 {
